@@ -51,15 +51,17 @@ NMapplyFilters <- function(data,file,text,lines,invert=FALSE,as.fun,quiet) {
 
 ### if data is a list of data and meta, we need to split it out and
 ### remember to update meta. This is needed for NMscanData, not
-### NMscanInput. We leave meta data untouched.
-    details <- FALSE
-    data.meta <- list()
-    if(is.list(data) && !is.data.frame(data)){
-        data.meta <- data$meta
-        data <- data$data
-        details <- TRUE
-    }
+### NMscanInput. We leave meta data untouched. This part is due to a previous design of NMscanInput. 
+    ## details <- FALSE
+    ## data.meta <- list()
+    ## if(is.list(data) && !is.data.frame(data)){
+    ##     data.meta <- data$meta
+    ##     data <- data$data
+    ##     details <- TRUE
+    ## }
     
+    data.meta <- NMinfoDT(data)
+
     text2 <- NMreadSection(lines=lines,section="DATA",keepComments=FALSE)
     text3 <- sub(";.*$","",text2)
 
@@ -192,6 +194,7 @@ NMapplyFilters <- function(data,file,text,lines,invert=FALSE,as.fun,quiet) {
     }
     
     data <- as.fun(data)
+    
     writeNMinfo(data,meta=data.meta,append=TRUE)
     data
  
