@@ -5,11 +5,33 @@
 ##'     mentioned in $DATA is used. dir.data will be used as the path,
 ##'     and the existence of the file in that directory is not
 ##'     checked.
+##' @param file.mod The input control stream. Default is to look for
+##'     \"file\" with extension changed to .mod (PSN style). You can
+##'     also supply the path to the file, or you can provide a
+##'     function that translates the output file path to the input
+##'     file path. The default behavior can be configured using
+##'     NMdataConf. See dir.data too.
 ##' @return The path to the input data file.
+##' @export
 
-### To be used internally so far - don't export
+NMextractDataFile <- function(file,dir.data=NULL,file.mod){
 
-NMextractDataFile <- function(file,dir.data=NULL){
+    if(missing(file.mod)) file.mod <- NULL
+    file.mod <- NMdataDecideOption("file.mod",file.mod)
+
+    if(!is.null(file.mod) && !is.null(dir.data)) {
+        messageWrap("Both file.mod and dir.data are non-NULL. Not allowed.",
+                    fun.msg=stop)
+    }
+    if(is.null(dir.data)) {
+        
+        file.mod <- NMdataDecideOption("file.mod",file.mod)
+        file.find.data <- file.mod(file)
+
+        if(!file.exists(file.find.data)) {
+            messageWrap("control stream (.mod) not found. Default is to look next to .lst file. See argument file.mod if you want to look elsewhere. If you don't have a .mod file, see the dir.data argument. Input data not used.",fun.msg=warning)
+        }
+    }
     
     ## get input data file name. Nonmem manual says:
 ###  The first character string appearing after $DATA is the name of the file
@@ -41,10 +63,13 @@ NMextractDataFile <- function(file,dir.data=NULL){
     exists.file <- file.exists(path.data)
     exists.file.rds <- file.exists(path.data.rds)
 
-    return(list(path=path.data
-               ,path.rds=path.data.rds
-               ,exists.file=exists.file
-               ,exists.file.rds=exists.file.rds
-               ,string=string.path.data))
-
+    return(list(
+    DATA=lines.data
+   ,string=string.path.data
+   ,path=path.data
+   ,path.rds=path.data.rds
+   ,exists.file=exists.file
+   ,exists.file.rds=exists.file.rds
+    ))
+    
 }
