@@ -25,43 +25,35 @@
 ##'     configured using NMdataConf.
 ##' @param args.rds A list of arguments to be passed to saveRDS.
 ##' @param args.RData A list of arguments to be passed to save.
-##' @param col.flag Name of a numeric column with zero value for rows
+##' @param col.flagn Name of a numeric column with zero value for rows
 ##'     to include in Nonmem run, non-zero for rows to skip. The
-##'     argument is only used for generating the proposed text to
+##'     argument is only used for generating the proposed $DATA text to
 ##'     paste into the Nonmem control stream. To skip this feature,
-##'     use col.flag=NULL.
-##' @param nmdir.data For the $DATA text proposal only. The path to
-##'     the input datafile to be used in the Nonmem $DATA
-##'     section. Often, a relative path to the actual Nonmem run is
-##'     wanted here.
-##' @param nm.copy For the $DATA text proposal only. If you plan to
-##'     rename columns in Nonmem $DATA, NMwriteData can adjust the
-##'     suggested $DATA text. If you plan to use CONC as DV in Nonmem,
-##'     you can include nm.rename=c(DV="CONC").
-##' @param nm.rename For the $DATA text proposal only. If you plan to
-##'     rename columns in Nonmem $DATA, NMwriteData can adjust the
-##'     suggested $DATA text. If you plan to use BBW instead of BWBASE
-##'     in Nonmem, consider nm.rename=c(BWBASE="BBW"). The result is
-##'     different from nm.copy since the nm.copy syntax is only
-##'     allowed by Nonmem for certain standard column names such as
-##'     DV.
-##' @param nm.drop Only used for generation of proposed text for
-##'     Nonmem control stream. Columns to drop in Nonmem $DATA. This
-##'     has two implications. One is that the proposed $DATA indicates
-##'     =DROP after the given column names. The other that in case it
-##'     is a non-numeric column, succeeding columns can still be
-##'     included.
-##' @param nm.capitalize For the $DATA text proposal only. If TRUE,
-##'     the suggested text for Nonmem will only contain capital
-##'     letters in column names.
-##' @param allow.char.TIME For the $DATA text proposal only. Assume
-##'     Nonmem can read TIME even if it can't be translated to
-##'     numeric. This is necessary if using the 00:00 format. Default
-##'     is TRUE.
+##'     use col.flagn=NULL.
 ##' @param quiet The default is to give some information along the way
 ##'     on what data is found. But consider setting this to TRUE for
 ##'     non-interactive use. Default can be configured using
 ##'     NMdataConf.
+##' @param args.NMgenText List of arguments to pass to NMgenText - the
+##'     function that generates text suggestion for INPUT and DATA
+##'     sections in the NONMEM control stream. You can use these
+##'     arguments to get a text suggestion you an use directly in
+##'     NONMEM - and NwriteSection can even update multiple NONMEM
+##'     control streams based on the result. This will update your
+##'     control streams to match your new data file with just one
+##'     command.
+##' @param nmdir.data Deprecated, use
+##'     args.NMgenText=list(dir.data="your/path") instead.
+##' @param nm.copy Deprecated, use
+##'     args.NMgenText=list(copy=c(newname="existing")) instead.
+##' @param nm.rename Deprecated, use
+##'     args.NMgenText=list(rename=c(newname="existing")) instead.
+##' @param nm.drop Deprecated, use
+##'     args.NMgenText=list(drop=c("column")) instead.
+##' @param nm.capitalize Deprecated, use
+##'     args.NMgenText=list(capitalize=TRUE) instead.
+##' @param allow.char.TIME Deprecated, use
+##'     args.NMgenText=list(allow.char.TIME=TRUE) instead.
 ##' @return Text for inclusion in Nonmem control stream, invisibly.
 ##' @details When writing csv files, the file will be
 ##'     comma-separated. Because Nonmem does not support quoted
@@ -72,7 +64,7 @@
 ##' of the data columns. Once a column is reached that Nonmem will not
 ##' be able to read as a numeric and column is not in nm.drop, the list
 ##' is stopped. Only exception is TIME which is not tested for whether
-##' character or not.
+##' character or not. 
 ##' 
 ##' @family Nonmem
 ##' @export
@@ -80,21 +72,18 @@
 
 NMwriteData <- function(data,file,write.csv=TRUE,write.rds=write.csv,
                         write.RData=FALSE,script,args.stamp,
-                        args.fwrite, args.rds,args.RData,nm.drop,
-                        nmdir.data,col.flag="FLAG", nm.rename,nm.copy,
-                        nm.capitalize=FALSE,allow.char.TIME=TRUE,
-                        quiet){
-    
-#### Section start: Dummy variables, only not to get NOTE's in pacakge checks ####
-    
+                        args.fwrite, args.rds,args.RData,
+                        quiet,args.NMgenText,
+### seprecated NMgenText arguments
+                        nm.drop,
+                        nmdir.data,col.flagn, nm.rename,nm.copy,
+                        nm.capitalize,allow.char.TIME){
+
+#### Section start: Dummy variables, only not to get NOTE's in pacakge checks ####    
     TIME <- NULL 
-    name.nm <- NULL
     comma.ok <- NULL
     include <- NULL
-    name.copy <- NULL
     numeric.ok <- NULL
-    occ.cum <- NULL
-    name.rename <- NULL
 
 ### Section end: Dummy variables, only not to get NOTE's in pacakge checks
 
@@ -104,8 +93,6 @@ NMwriteData <- function(data,file,write.csv=TRUE,write.rds=write.csv,
     if(missing(args.fwrite)) args.fwrite <- NULL
     args.fread <- NMdataDecideOption("args.fwrite",args.fwrite)
 
-    if(missing(nmdir.data)) nmdir.data <- NULL
-    
     stopifnot(is.data.frame(data)) 
     if(missing(file)||is.null(file)){
         file <- NULL
@@ -122,6 +109,50 @@ NMwriteData <- function(data,file,write.csv=TRUE,write.rds=write.csv,
 
     if(missing(quiet)) quiet <- NULL
     quiet <- NMdataDecideOption("quiet",quiet)
+### Section end: Dummy variables, only not to get NOTE's in pacakge checks
+    if(missing(col.flagn)) col.flagn <- NULL
+    col.flagn <- NMdataDecideOption("col.flagn",col.flagn)
+
+    
+    args.text.depr <- c(
+        "nm.drop",
+        "nmdir.data",
+        "col.flagn",
+        "nm.rename",
+        "nm.copy",
+        "nm.capitalize",
+        "allow.char.TIME")
+
+    ## if args.NMgenText is used, the deprecated ags are not allowed
+    all.args <- as.list(match.call(expand.dots=FALSE))
+    if(missing(args.NMgenText)) {
+        args.NMgenText <- NULL
+    } else {
+        if(any(args.text.depr%in%names(all.args))){
+            messageWrap(paste0("Please only use args.NMgenText and not the deprecated arguments ",paste(args.text.depr,collapse=", "),". Those are only accepted if you aren't using the args.NMgenText argument yet.")
+                       ,fun.msg=stop)
+        }
+    }
+    used.args.depr <- all.args[names(all.args)%in%args.text.depr]
+    if(length(used.args.depr)>0){
+        names.used.ad <- names(used.args.depr)
+        names.used.ad[names.used.ad=="nm.drop"] <- "drop"
+        names.used.ad[names.used.ad=="nmdir.data"] <- "dir.data"
+        ##    names.used.ad[names.used.ad=="col.flagn"] <- "col.flagn"
+        names.used.ad[names.used.ad=="nm.rename"] <- "rename"
+        names.used.ad[names.used.ad=="nm.copy"] <- "copy"
+        names.used.ad[names.used.ad=="nm.capitalize"] <- "capitalize"
+        ##    names.used.ad[names.used.ad=="allow.char.TIME"] <- "allow.char.TIME"
+        names(used.args.depr) <- names.used.ad
+        args.NMgenText <- used.args.depr
+    }
+### allow overwriting quiet
+    if(!"quiet"%in%names(args.NMgenText))  args.NMgenText$quiet <- quiet
+    if(!"col.flagn"%in%names(args.NMgenText))  args.NMgenText$col.flagn <- col.flagn
+    ## do not allow setting data and file. If that is wanted, use NMgenText instead.
+    if(any(c("data","file")%in%names(args.NMgenText))){
+        messageWrap("data and file are not allowed in args.NMgenText. If you want to set those, use NMgenText directly instead.",fun.msg=stop)
+    }
     
 ### stamp arguments
     doStamp <- TRUE
@@ -163,146 +194,47 @@ NMwriteData <- function(data,file,write.csv=TRUE,write.rds=write.csv,
         }
     }
 
-    if(missing(nm.drop)) {
-        nm.drop <- NULL
-    } else {
-        if(!is.null(nm.drop) && !is.character(nm.drop) ) {
-            stop("If supplied, nm.drop must be of type character.")
-        }
-        if(any(is.na(nm.drop)|nm.drop=="")){
-            stop("nm.drop cannot contain empty strings and NA's.")
-        }
-    }
+
+
     
 ###  Section end: Process arguments
 
     data.dt <- copy(as.data.table(data))
 
     ## Check if character variables contain commas
-    ## This would cause trouble when writing csv    
+    ## This would cause trouble when writing csv
+    
     has.no.comma <- data.dt[,lapply(.SD,function(x){is.numeric(x)||!any(grepl(",",as.character(x)))})]
 
-    ## only report numerics to user.
-    ## Only report until first not interpretable as numeric. 
-    as.num.ok <- data.dt[,lapply(.SD,NMisNumeric)]
+    comma.ok=as.logical(has.no.comma[1])
 
-    
-    ## Allow TIME even if non-numeric. 
-    if(allow.char.TIME){
-        if("TIME"%in%colnames(data.dt) &&
-           as.num.ok[,TIME==FALSE]) {
-            as.num.ok[,TIME:=TRUE]
-        }
-    }
-    
-    dt.num.ok <- data.table(
-        col=colnames(as.num.ok)
-       ,numeric.ok=as.logical(as.num.ok[1])
-       ,comma.ok=as.logical(has.no.comma[1])
-    )
-
-    ## if wanted, use only capital letters for column names in Nonmem
-    dt.num.ok[,name.nm:=col]
-    if(nm.capitalize){
-        dt.num.ok[,name.nm:=toupper(name.nm)]
-    }
-    
-    ## drop .'s from names since they are not allowed in nonmem
-    ##    dt.num.ok[,name.nm:=gsub("\\.","",name.nm)]
-    
-    if(dt.num.ok[,any(!comma.ok)]){
-        messageWrap(paste("You must avoid commas in data values. They will curropt the csv file, so get rid of them before saving data. Comma found in column(s):",paste(dt.num.ok[comma.ok==FALSE,col],sep=", ")),
+    if(any(!comma.ok)){
+        messageWrap(paste("You must avoid commas in data values. They will curropt the csv file, so get rid of them before saving data. Comma found in column(s):",paste(colnames(data.dt)[comma.ok==FALSE],sep=", ")),
                     fun.msg=stop)
     }
 
     
     ## if any repetetions, give warning, and add numbers
     
-### this is input column names. 
-    if(dt.num.ok[,any(duplicated(col))]) {
+### this is input column names.
+    cnames <- colnames(data.dt)
+    if(any(duplicated(cnames))) {
         warning(paste("Duplicated column name(s) in data:",
-                      paste0(dt.num.ok[duplicated(col),unique(col)],collapse=", ")
+                      paste0(unique(cnames[duplicated(cnames)]),collapse=", ")
                       ))
     }
 
-
-    ## apply DROP
-    dt.num.ok[,drop:=FALSE]
-    if(!is.null(nm.drop)){
-        dt.num.ok[col%in%nm.drop,name.nm:=paste0(name.nm,"=DROP")]
-        dt.num.ok[col%in%nm.drop,drop:=TRUE]
-        drops.not.used <- nm.drop[!nm.drop%in%dt.num.ok[,col]]
-        if(length(drops.not.used)){
-            warning("Elements in nm.drop not found as columns in data:",paste(drops.not.used,collapse=", "))
-        }
-    }
-    
-    ## apply nm.copy
-    if(!missing(nm.copy)){
-        names.copy <- names(nm.copy)
-        dt.num.ok[,name.copy:=names.copy[match(dt.num.ok[,col],nm.copy)]]
-        dt.num.ok[!is.na(name.copy),name.nm:=paste0(name.copy,"=",col)]
-    }
-
-    ## apply nm.rename
-    if(!missing(nm.rename)){
-        names.rename <- names(nm.rename)
-        dt.num.ok[,name.rename:=names.rename[match(dt.num.ok[,col],nm.rename)]]
-        dt.num.ok[!is.na(name.rename),name.nm:=name.rename]
-    }
-    
-    
-    
-    dt.num.ok[,include:=cumsum(!numeric.ok&!drop)<1]
-
-    dt.num.ok[include==TRUE,occ.cum:=1:.N,by=name.nm]
-    if(dt.num.ok[occ.cum>1,.N]>0) {
-        warning(paste("Duplicated column name(s) in data after transforming to upper case for Nonmem:\n",
-                      paste0(dt.num.ok[occ.cum>1,unique(name.nm)],collapse=", "),"\n",
-                      "Names have been numbered in $INPUT proposal."
-                      ))
-    }
-    dt.num.ok[occ.cum>1,name.nm:=paste0(name.nm,occ.cum)]
-
-    colnames.nm <- dt.num.ok[include==TRUE,name.nm]
-
-    
-    nmfile <- file
-
-    if(!is.null(nmdir.data)&&!is.null(nmfile)){
-        nmfile <- file.path(nmdir.data,basename(nmfile))
-    } else {
-        nmfile <- "<data file>"
-    }
-
-    text.nm.input <- strwrap(
-        paste0("$INPUT ",paste(colnames.nm,collapse=" "))
-    )
-    text.nm.data <- c(paste0("$DATA ", nmfile)
-                     ,paste0("IGN=@")
-                      )
-
-    if(!is.null(col.flag)&&col.flag%in%colnames.nm){
-        text.nm.data <- c(text.nm.data,
-                          paste0("IGNORE=(",col.flag,".NE.0)")
-                          )
-    }
-    
-    text.nm <- c(
-        text.nm.input
-       ,text.nm.data
-    )
-
     files.written=c()
     if(write.csv){
         file.csv <- fnExtension(file,".csv")
-
+        
         do.call(fwrite,append(list(x=data,file=file.csv),args.fwrite))
         ## fwrite      (data,na=".",quote=FALSE,row.names=FALSE,scipen=0,file=file.csv)
         files.written <- c(files.written,file.csv)
         if(doStamp){
             
-            data <- do.call(NMstamp,append(list(data=data,writtenTo=file.csv),args.stamp))
+            ## data <- do.call(NMstamp,append(list(data=data,writtenTo=file.csv),args.stamp))
+            do.call(NMstamp,append(list(data=data,writtenTo=file.csv),args.stamp))
             data.meta.csv <- NMinfo(data,"dataCreate")
             data.meta.csv <- data.table(parameter=names(data.meta.csv)
                                        ,value=unlist(lapply(data.meta.csv,as.character)))
@@ -339,10 +271,17 @@ NMwriteData <- function(data,file,write.csv=TRUE,write.rds=write.csv,
 
         }
         
-        message("For NonMem:\n",
-                paste(text.nm,collapse="\n"))
     }
     
-    invisible(list(INPUT=text.nm.input,DATA=text.nm.data))
+    ## NONMEM text
+    
+    NMtext <- do.call(NMgenText,
+                      append(
+                          list(data=data.dt,file=file)
+                         ,args.NMgenText)
+                      )
+
+    
+    invisible(list(INPUT=NMtext$INPUT,DATA=NMtext$DATA))
 
 }
