@@ -8,6 +8,7 @@
 ##' @param by optional covariates will be searched for in combinations of
 ##'     values in these columns. Often by will be either empty or ID. But
 ##'     it can also be both say c("ID","DRUG") or c("ID","TRT").
+##' @param cols.id Deprecated. Use by instead.
 ##' @param as.fun The default is to return a data.table if data is a data.table
 ##'     and return a data.frame in all other cases. Pass a function in as.fun to
 ##'     convert to something else. If data is not a data.table, the default can
@@ -15,15 +16,34 @@
 ##' @details Use this to exclude columns that are constant within by. If
 ##'     by=ID, this could be to get only time-varying covariates.
 ##' @return a data set with as many rows as in data.
+##' @examples
+##' dt1 <- data.frame(ID=c(1,1,2,2),
+##'                   OCC=c(1,2,1,2),
+##'                ## ID level
+##'                   eta1=c(1,1,3,3),
+##'                ## occasion level
+##'                   eta2=c(1,3,1,5),
+##'                ## not used
+##'                   eta3=0
+##'                )
+##' ## model level
+##' findCovs(dt1)
+##' ## ID level
+##' findCovs(dt1,"ID")
+##' ## acual ID level
+##' findVars(findCovs(dt1,"ID"))
+##' ## occasion level
+##' findCovs(findVars(dt1,"ID"),c("ID","OCC"))
 ##' @family DataCreate
 ##' @import data.table
 ##' @export
 
 
-
-findVars <- function(data,by=NULL,as.fun=NULL){
+findVars <- function(data,by=NULL,cols.id,as.fun=NULL){
 
     ## check arguments
+    if(!missing(cols.id)) .Deprecated("by",msg="cols.id argument deprecated. Use by instead.")
+    
     if(!is.data.frame(data)){
         stop("data must be a data.frame (or data.table)")
     }
