@@ -14,7 +14,7 @@
 ##'     ordered like df1.
 ##' @param df2 A data.frame that will be merged onto df1.
 ##' @param by The column(s) to merge by. Character string
-##'     (vector). Must be supplied.
+##'     (vector). by or by.x and by.y must be supplied.
 ##' @param as.fun The default is to return a data.table if df1 is a
 ##'     data.table and return a data.frame in all other cases. Pass a
 ##'     function in as.fun to convert to something else.
@@ -33,8 +33,10 @@
 ##' @param track.msg If using mergeCheck inside other functions, it
 ##'     can be useful to use track.msg=TRUE. This will add information
 ##'     to messages/warnings/errors that they came from mergCheck.
-##' @param ... additional arguments passed to merge. If all is among
-##'     them, an error will be returned.
+##' @param quiet If FALSE, the names of the added columns are
+##'     reported. Default value controlled by NMdataConf.
+##' @param ... additional arguments passed to data.table::merge. If
+##'     all is among them, an error will be returned.
 ##' @details Besides merging and checking rows, mergeCheck makes sure
 ##'     the order in df1 is retained in the resulting data. Also, a
 ##'     warning is given if column names are overlapping, making merge
@@ -49,15 +51,18 @@
 ##' @importFrom stats setNames
 ##' @return a data.frame resulting from merging df1 and df2. Class as
 ##'     defined by as.fun.
+##' 
+##'
 ##' @export
 
-mergeCheck <- function(df1,df2,by,as.fun=NULL,fun.commoncols=base::warning,ncols.expect,track.msg=FALSE,...){
+mergeCheck <- function(df1,df2,by,fun.commoncols=base::warning,ncols.expect,track.msg=FALSE,quiet,as.fun,...){
 
 
 #### Section start: Dummy variables, only not to get NOTE's in pacakge checks ####
 
     N.result <- NULL
     N.df1 <- NULL
+    N <- NULL
 
 ###  Section end: Dummy variables, only not to get NOTE's in pacakge checks
     
@@ -69,6 +74,8 @@ mergeCheck <- function(df1,df2,by,as.fun=NULL,fun.commoncols=base::warning,ncols
     if(length(name.df1)!=1) name.df1 <- "df1"
     if(length(name.df2)!=1) name.df2 <- "df2"
 
+    if(missing(quiet)) quiet <- NULL
+    quiet <- NMdataDecideOption("quiet",quiet)
     
     name.df3 <- "merged.df"
     if("all"%in%names(list(...))) {
@@ -99,12 +106,19 @@ mergeCheck <- function(df1,df2,by,as.fun=NULL,fun.commoncols=base::warning,ncols
         df2 <- as.data.table(df2)
     }
 
+    if(missing(as.fun)) as.fun <- NULL
+    if(df1.was.dt && is.null(as.fun)) as.fun <- "data.table"
+    as.fun <- NMdataDecideOption("as.fun",as.fun)
+
+    ### this has to be refined. by.x+by.y will do too.
+    ## if(missing(by) || is.null(by)) stop("The \"by\" argument must be supplied.") 
+
     if(!missing(by)){
         cols.common <- intersect(colnames(df1),colnames(df2))
         cols.com.notby <- setdiff(cols.common,by)
         commoncols.found <- FALSE
         if(length(cols.com.notby)) {
-            messageWrap(paste0("df1 and df2 have common column names not being merged by. This will create new column names in output. Common but not merged by: ",paste(cols.com.notby,collapse=","),"."),
+            messageWrap(paste0("df1 and df2 have common column names not being merged by. This will create new column names in output. Common but not merged by: ",paste(cols.com.notby,collapse=", "),"."),
                         fun.msg=fun.commoncols,track.msg=track.msg)
             commoncols.found <- TRUE
         }
@@ -123,6 +137,8 @@ mergeCheck <- function(df1,df2,by,as.fun=NULL,fun.commoncols=base::warning,ncols
 
     rows.disappeared <- !(all(df1[,get(rowcol)]%in%df3[,get(rowcol)]))
     rows.created <- !(all(df3[,get(rowcol)]%in%df1[,get(rowcol)]))
+### this has to be tested before activated 
+    rows.dup  <- df3[,.N,by=rowcol][,any(N>1)]
     rows.number.changed <- nrow(df1)!=nrow(df3)
 
     if(any(c(rows.disappeared,rows.created,rows.number.changed))){
@@ -131,6 +147,7 @@ mergeCheck <- function(df1,df2,by,as.fun=NULL,fun.commoncols=base::warning,ncols
             messageWrap("Number of rows changed during merge.\n",fun.msg=message,track.msg=track.msg)
         }
         if(rows.disappeared) messageWrap("Rows disappeared during merge.",fun.msg=message,track.msg=track.msg)
+        if(rows.dup) messageWrap("Rows duplicated during merge.",fun.msg=message,track.msg=track.msg)
         if(rows.created) messageWrap("New rows appeared during merge.",fun.msg=message,track.msg=track.msg)
         
         dims.rep <- dims(list.data=
@@ -138,8 +155,8 @@ mergeCheck <- function(df1,df2,by,as.fun=NULL,fun.commoncols=base::warning,ncols
                          )
         
         message("Overview of dimensions of input and output data:\n",
-            paste0(capture.output(dims.rep), collapse = "\n"),"\n"
-        )
+                paste0(capture.output(dims.rep), collapse = "\n"),"\n"
+                )
         
         dtcheck <- merge(df1[,.N,by=by],
                          df3[,.N,by=by]
@@ -160,20 +177,22 @@ mergeCheck <- function(df1,df2,by,as.fun=NULL,fun.commoncols=base::warning,ncols
         df3[,(rowcol):=NULL]
     }
 
+    newcols <- setdiff(colnames(df3),colnames(df1))
 ### checking number of new columns
     if(!missing(ncols.expect)) {
         df1[,(rowcol):=NULL]
         n.newcols <- ncol(df3)-ncol(df1)
         if(n.newcols!=ncols.expect) {
-            newcols <- setdiff(colnames(df3),colnames(df1))
             messageWrap(sprintf("Number of new columns (%d) does not mactch the expected (%d). New columns are: %s.",n.newcols,ncols.expect,paste(newcols,", ")),fun.msg=stop,track.msg=track.msg)
         }
     }
-
-    if(df1.was.dt && is.null(as.fun)) as.fun <- "data.table"
-    as.fun <- NMdataDecideOption("as.fun",as.fun)
-    df3 <- as.fun(df3)
     
+    df3 <- as.fun(df3)
+
+    if(!quiet){
+        msg <- paste0("The following columns were added: ",paste(newcols,collapse=", "))
+        message(msg)
+    }
     
     df3
 }
