@@ -16,7 +16,7 @@ test_that("basic",{
 })
 
 
-test_that("basic",{
+test_that("basic2",{
 
     fileRef <- "testReference/findVars2.rds"
     
@@ -32,3 +32,9 @@ test_that("basic",{
     expect_equal_to_reference(list(r1,r2),fileRef,version=2)
 
 })
+
+test_that("deprecated cols.id",
+          expect_warning(
+              findVars(data.frame(x=1),cols.id="w")
+          )
+          )
